@@ -1,14 +1,20 @@
 import configparser
+# from logging import getLogger,  FileHandler, ERROR
+from logging import ERROR, StreamHandler, getLogger
 from pathlib import Path
 from unittest import TestCase
-from pymongo import errors as py_errors, MongoClient
-from bson import ObjectId, DBRef
-from edman import Config, DB
+
+from bson import DBRef, ObjectId
+from edman import DB, Config
+from pymongo import MongoClient
+from pymongo import errors as py_errors
+
 from edman_web.search_manager import SearchManager
 
+
 class TestSearchManager(TestCase):
     db_server_connect = False
-    test_ini = []
+    test_ini: dict = {}
     client = None
 
     @classmethod
@@ -62,6 +68,18 @@ class TestSearchManager(TestCase):
         # else:
         #     cls.search = Search()
 
+        cls.logger = getLogger()
+
+        # ログを画面に出力
+        ch = StreamHandler()
+        ch.setLevel(ERROR)  # ハンドラーにもそれぞれログレベル、フォーマットの設定が可能
+        cls.logger.addHandler(ch)  # StreamHandlerの追加
+
+        # ログをファイルに出力
+        # fh = FileHandler('./tests.log')  # 引数には出力ファイルのパスを指定
+        # fh.setLevel(ERROR)  # ハンドラーには、logger以下のログレベルを設定することは出来ない(この場合、DEBUGは不可)
+        # cls.logger.addHandler(fh)  # FileHandlerの追加
+
     @classmethod
     def tearDownClass(cls):
         if cls.db_server_connect:
@@ -130,9 +148,9 @@ class TestSearchManager(TestCase):
             insert_result = self.testdb[i['col']].insert_one(i['doc'])
             result.update({i['col']: insert_result.inserted_id})
 
-
         all_docs = self.search_manager.get_documents(2, doc_col, doc_id,
-                                             parent_depth=0, child_depth=0)
+                                                     parent_depth=0,
+                                                     child_depth=0)
         expected = {
             parent_col: {
                 'name': 'parent',
